<?php
//------------------------------------------------------------------------------------
//                                  COPYRIGHT NOTICE
//------------------------------------------------------------------------------------
//LAST POST - FORUMS
//------------------------------------------------------------------------------------
//The included php scripts (code) is the exclusive copyright of EIP Software LLC. 
//(http://www.eipsoftware.com). 
//
//EIP Software LLC grants holder a non-exclusive license and the use of the code is 
//to be used only in connection with the XenForo forum software. Any deviation or 
//violation of EIP Software LLC or XenForo terms of use will immediately 
//revoke any implied or explicitly stated rights granted to you to use the following 
//code.  The code is copyrighted and may not be copied, even if modified or merged 
//with other data or software.
//
//By using the code and XenForo forum software you agree to be bound by EIP 
//Software LLC's and XenForo Terms of Service as well as these 
//additional terms and conditions. 
//
//XenForo forum software's use of any kind of part or all of XenForo
//software requires a separate license from XenForo. You may not 
//commercially redistribute and or part of LAST POST - FORUMS or XenForo's forum
//software.
//
//This code is distributed in the hope that it will be useful, but WITHOUT ANY 
//WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
//PARTICULAR PURPOSE. завершенный!
//------------------------------------------------------------------------------------
//
//------------------------------------------------------------------------------------
//cls_mypdo.php:    	run database queries
//called by:            cls_lpatch.php
//inputs:               NONE
//uses:                 NONE
//returns:				$arr_Result		// array of the sql results
//						$bol_Success	// if the qry completed successfully
//outputs:              class
//updates:              2009-04-21 :: mm :: updated changed to encapsulate into a class
//                      2009-05-23 :: mm :: added fx _construct, fx closeconnection
//						2010-01-14 :: mm :: change fx __construct to allow for different levels
//------------------------------------------------------------------------------------
//version:              1.01
//status:               CHECKED IN
//------------------------------------------------------------------------------------
class eipPDO extends PDO
{
	private $dsn;							//to hold the connection string to the database
	private $args	= Array('sql'=>null, 'access'=>'READ','SuppressErrors'=>TRUE, 'ReturnID'=>false);	//runtime arguments
	private $stmt;							//sql statement
	private $id;							//id that was created for INSERT statement
	private $arr_Result;					//store the results for a select statement
	private $bol_Success 		= false;	//did the query complete successfully

	public function getResults($args){return($this->ReturnResults($args));}
	public function getID(){return($this->id);}
	public function __construct($userOptions)
	{//overrides pdo construct
		try
		{
			$lp = new eipLastPostxfconfig($userOptions['forumDirectory']);
			$this->dsn = "mysql" .":host=".$lp->getValue("db","host") . ";dbname=". $lp->getValue("db","dbname");
			parent::__construct($this->dsn,$lp->getValue("db","username"),$lp->getValue("db","password"));
		}
		catch (PDOException $e)
		{
    		if(!$this->args['SuppressErrors']){echo("Query failed: " . $e->getMessage());}
	    }
	}

	private function ProcessArgs($args)
	{
		try
		{
			if(is_array($args)){$this->args = array_merge($this->args,$args);};		//merge the args into an array
			if($this->args['sql']==null){throw new ExceptionHandler("Database Query not specified");}
			$this->args['access'] =  strtoupper($this->args['access']);				//conver the string to uppercase
		}
	    catch(ExceptionHandler $e)
	    {
	        $e->ParseError('Invalid Arguments');
	    }
	}

	private function RunQuery()
	{
		try
		{
			switch($this->args['access'])
			{
				case "READ":
				{
					$this->stmt = $this->prepare($this->args['sql']);		//preparet the statement
					$this->stmt->setFetchMode(PDO::FETCH_ASSOC);			//set the fetch mode
					$this->stmt->execute();									//run the query
					$this->arr_Result = $this->stmt->fetchAll();			//store the results in the array
					$this->bol_Success = (count($this->arr_Result)>0) ? true : false;	//was it successful
					break;
				}
				case "UPDATE":
				{
					$this->beginTransaction();						//turn autocommit off
					$this->stmt	= $this->exec($this->args['sql']);	//run the qry
					if($this->args['ReturnID']){$this->id = $this->lastInsertId();}	//get the ID before committing transaction
					$this->bol_Success = $this->commit();			//commit the transaction
					if((!$this->bol_Success) && (!$this->args['SuppressErrors'])){throw new PDOException();}
					break;
				}
			}
		}
		catch (PDOException $e)
		{
			if(!$this->args['SuppressErrors']){echo("Query failed: " . $e->getMessage());}
		}
	}

	private function ReturnResults($args)
	{
		try
		{
			$this->ProcessArgs($args);										//process the args
			$this->RunQuery();												//run the query
			switch($this->args['access'])
			{
				case "READ":
				{
					if($this->bol_Success)
					{
						return($this->arr_Result);
					}
					else
					{
						return($this->bol_Success);
					}
					break;
				}
				case "UPDATE":
				{
					return($this->bol_Success);
					break;
				}
				default:
				{
					return(false);
				}
			}
		}
		catch(ExceptionHandler $e)
	    {
	        $e->ParseError('Invalid Results');
	    }
	}

	public function NewQuery($args)
	{
		$this->ProcessArgs($args);												//process the args
		$this->RunQuery();														//run the query
	}

	public function __destruct()
	{
		$this->stmt = null;	$this->arr_Result = null; $this->args = null;
	}
}
?>
